==> angular-0.9.11.tar.gz: test/core/registry_spec.dart <==
library registry_spec;

import '../_specs.dart';
import 'package:angular/angular_dynamic.dart';

main() {
  describe('RegistryMap', () {
    it('should allow for multiple registry keys to be added', () {
      var module = new Module()
          ..type(MyMap)
          ..type(A1)
          ..type(A2);

      var injector = ngDynamicApp().addModule(module).createInjector();
      expect(() {
        injector.get(MyMap);
      }).not.toThrow();
    });

    it('should iterate over all types', () {
      var module = new Module()
          ..type(MyMap)
          ..type(A1);

      var injector = ngDynamicApp().addModule(module).createInjector();
      var keys = [];
      var types = [];
      var map = injector.get(MyMap);
      map.forEach((k, t) { keys.add(k); types.add(t); });
      expect(keys).toEqual([new MyAnnotation('A'), new MyAnnotation('B')]);
      expect(types).toEqual([A1, A1]);
    });

    it('should safely ignore typedefs', () {
      var module = new Module()
          ..type(MyMap)
          ..value(MyTypedef, (String _) => null);

      var injector = ngDynamicApp().addModule(module).createInjector();
      expect(() => injector.get(MyMap), isNot(throws));
    });
  });
}

typedef void MyTypedef(String arg);

class MyMap extends AnnotationMap<MyAnnotation> {
  MyMap(Injector injector, MetadataExtractor metadataExtractor)
      : super(injector, metadataExtractor);
}


class MyAnnotation {
  final String name;

  const MyAnnotation(String this.name);

  toString() => name;
  get hashCode => name.hashCode;
  operator==(other) => this.name == other.name;
}

@MyAnnotation('A') @MyAnnotation('B') class A1 {}
@MyAnnotation('A') class A2 {}

==> angular-0.10.0.tar.gz: test/core/registry_spec.dart <==
library registry_spec;

import '../_specs.dart';
import 'package:angular/application_factory.dart';

main() {
  describe('RegistryMap', () {
    it('should allow for multiple registry keys to be added', () {
      var module = new Module()
          ..type(MyMap)
          ..type(A1)
          ..type(A2);

      var injector = applicationFactory().addModule(module).createInjector();
      expect(() {
        injector.get(MyMap);
      }).not.toThrow();
    });

    it('should iterate over all types', () {
      var module = new Module()
          ..type(MyMap)
          ..type(A1);

      var injector = applicationFactory().addModule(module).createInjector();
      var keys = [];
      var types = [];
      var map = injector.get(MyMap);
      map.forEach((k, t) { keys.add(k); types.add(t); });
      expect(keys).toEqual([new MyAnnotation('A'), new MyAnnotation('B')]);
      expect(types).toEqual([A1, A1]);
    });

    it('should safely ignore typedefs', () {
      var module = new Module()
          ..type(MyMap)
          ..value(MyTypedef, (String _) => null);

      var injector = applicationFactory().addModule(module).createInjector();
      expect(() => injector.get(MyMap), isNot(throws));
    });
  });
}

typedef void MyTypedef(String arg);

class MyMap extends AnnotationMap<MyAnnotation> {
  MyMap(Injector injector, MetadataExtractor metadataExtractor)
      : super(injector, metadataExtractor);
}


class MyAnnotation {
  final String name;

  const MyAnnotation(String this.name);

  toString() => name;
  get hashCode => name.hashCode;
  operator==(other) => this.name == other.name;
}

@MyAnnotation('A') @MyAnnotation('B') class A1 {}
@MyAnnotation('A') class A2 {}
